#[repr(C)]pub struct TestConfig {
pub src_port: u16,
pub dst_port: u16,
}Expand description
Configuration for the test program. If either field is not zero then the
test program will try to match these fields against the corresponding
fields in UDP packets. In that case, if a packet doesn’t match or it’s not
a UDP packet the program returns 0 without updating the TestResult. If
both fields are zero or the packet matches then TestResult is updated
and the program returns 1.
Fields
src_port: u16Source port to match. Any port matches if set to 0.
dst_port: u16Destination port to match. Any port matches if set to 0.